==> django_framework-0.1.83.tar.gz: django_framework-0.1.83/django_framework/helpers/data_collector_helper/data_collector.py <==
import arrow
import requests


import urllib2

class SimpleDataCollector(object):
    '''This one does nto allow conversion to Panda Dataframes!'''
    DATA_URL = 'https://data.chaienergy.net/data/{uid}/{stream_type}/?{params}'

    def __init__(self, uid, stream_type):
        uid = urllib2.quote(uid)
        self.uid = uid
        
        # we found a bug that did not properly convert '/' in incoding...which is valid
        if self.uid.find('/')>=0:
            self.uid.replace('/', '%2f')
        
        self.stream_type = stream_type

    def get_data(self, starttime = None, endtime = None, 
                 deltatime=None,
                 health = False,
                 stats= False,
                 interval = None,
                 show_interval = None,
                 aggregate = None,
                 timezone = None,
                 compress = None):
        
        params = self.format_params(starttime, endtime, deltatime, health, stats, interval, show_interval, aggregate, timezone, compress=compress)

        url = self.DATA_URL.format(uid = self.uid, stream_type = self.stream_type, params = params)

        meta = self.send_query(url = url)
        data = meta.pop('data')
        
        if len(data) == 0:
            return [], None # we override it to not error out!
            raise ValueError('No data was found!')

        return data, meta

    def format_params(self, starttime = None, endtime = None, 
                deltatime = None,
                 health = False,
                 stats= False,
                 interval = None,
                 show_interval = None,
                 aggregate = 'hour',
                 timezone = None,
                 compress = None):
        params = {}
        
        if deltatime is not None and starttime is None and endtime is None:
            starttime = arrow.utcnow().timestamp - int(deltatime)
            endtime   = arrow.utcnow().timestamp
        
        if starttime is not None:
            params['starttime'] = arrow.get(starttime).timestamp 
            
        if endtime is not None:
            params['endtime'] = arrow.get(endtime).timestamp 
        
        
        
        
        params['health'] = str(health).lower()
        params['stats'] = str(stats).lower()
        
        if interval != None:
            params['interval'] = str(int(interval))
            
        if show_interval != None:
            params['show_interval'] = 'true'
        
        if aggregate != None:
            params['aggregate'] = aggregate

        if timezone != None:
            params['timezone'] = timezone
            
        if compress != None:
            params['compress'] = int(compress)
        
        params['show_data'] = 'true'
        params['format'] = 'json'
    
    
        mystr = ''
        for i, v in params.iteritems():
            mystr += i + '=' + str(v) +'&'
    
        return mystr
    
    def send_query(self, url):
        response = requests.get(url = url)
        if response.status_code != 200:
            raise ValueError('There was a problem fetching the data: ' + url)
        
        return response.json()
    

class DataCollector(SimpleDataCollector):
    
    
    def get_data(self, convert_to_df = False, **kwargs):
        
        data, meta = super(DataCollector, self).get_data(**kwargs)
        
        if meta == None:
            data = None

        elif convert_to_df == True:
            data = self.convert_to_df(data = data, headers = meta['headers'])
            
        return data, meta
    
    def convert_to_df(self, data, headers):
        import pandas as pd
        df = pd.DataFrame(data)
        df.columns = headers

        df['value'] = df['value'].astype(dtype = 'float64')
        df.set_index(pd.DatetimeIndex(df['time'].astype('datetime64[s]'), tz = 'UTC'), inplace = True)
        df.sort_index(inplace = True)

        return df
if __name__ == '__main__':
#     dc = DataCollector(uid = '1520 PRINCETON ST #1 SANTA MONICA CA 90404', stream_type = 3)
    dc = DataCollector(uid = 'SCE_62GT4UZIX', stream_type = 3)
    d, f = dc.get_data(starttime = 1470517200, endtime = 1472432400, convert_to_df = True, aggregate = 'hour')
    
    print(d)
    print(f)

==> django_framework-0.1.84.tar.gz: django_framework-0.1.84/django_framework/helpers/data_collector_helper/data_collector.py <==
import arrow
import requests


import urllib2

class SimpleDataCollector(object):
    '''This one does nto allow conversion to Panda Dataframes!'''
    DATA_URL = 'https://data.chaienergy.net/data/{uid}/{stream_type}/?{params}'

    def __init__(self, uid, stream_type):
        uid = urllib2.quote(uid)
        self.uid = uid
        
        # we found a bug that did not properly convert '/' in incoding...which is valid
        if self.uid.find('/')>=0:
            self.uid = self.uid.replace('/', '%2f')
        
        self.stream_type = stream_type

    def get_data(self, starttime = None, endtime = None, 
                 deltatime=None,
                 health = False,
                 stats= False,
                 interval = None,
                 show_interval = None,
                 aggregate = None,
                 timezone = None,
                 compress = None):
        
        params = self.format_params(starttime, endtime, deltatime, health, stats, interval, show_interval, aggregate, timezone, compress=compress)

        url = self.DATA_URL.format(uid = self.uid, stream_type = self.stream_type, params = params)

        meta = self.send_query(url = url)
        data = meta.pop('data')
        
        if len(data) == 0:
            return [], None # we override it to not error out!
            raise ValueError('No data was found!')

        return data, meta

    def format_params(self, starttime = None, endtime = None, 
                deltatime = None,
                 health = False,
                 stats= False,
                 interval = None,
                 show_interval = None,
                 aggregate = 'hour',
                 timezone = None,
                 compress = None):
        params = {}
        
        if deltatime is not None and starttime is None and endtime is None:
            starttime = arrow.utcnow().timestamp - int(deltatime)
            endtime   = arrow.utcnow().timestamp
        
        if starttime is not None:
            params['starttime'] = arrow.get(starttime).timestamp 
            
        if endtime is not None:
            params['endtime'] = arrow.get(endtime).timestamp 
        
        
        
        
        params['health'] = str(health).lower()
        params['stats'] = str(stats).lower()
        
        if interval != None:
            params['interval'] = str(int(interval))
            
        if show_interval != None:
            params['show_interval'] = 'true'
        
        if aggregate != None:
            params['aggregate'] = aggregate

        if timezone != None:
            params['timezone'] = timezone
            
        if compress != None:
            params['compress'] = int(compress)
        
        params['show_data'] = 'true'
        params['format'] = 'json'
    
    
        mystr = ''
        for i, v in params.iteritems():
            mystr += i + '=' + str(v) +'&'
    
        return mystr
    
    def send_query(self, url):
        response = requests.get(url = url)
        if response.status_code != 200:
            raise ValueError('There was a problem fetching the data: ' + url)
        
        return response.json()
    

class DataCollector(SimpleDataCollector):
    
    
    def get_data(self, convert_to_df = False, **kwargs):
        
        data, meta = super(DataCollector, self).get_data(**kwargs)
        
        if meta == None:
            data = None

        elif convert_to_df == True:
            data = self.convert_to_df(data = data, headers = meta['headers'])
            
        return data, meta
    
    def convert_to_df(self, data, headers):
        import pandas as pd
        df = pd.DataFrame(data)
        df.columns = headers

        df['value'] = df['value'].astype(dtype = 'float64')
        df.set_index(pd.DatetimeIndex(df['time'].astype('datetime64[s]'), tz = 'UTC'), inplace = True)
        df.sort_index(inplace = True)

        return df
if __name__ == '__main__':
#     dc = DataCollector(uid = '1520 PRINCETON ST #1 SANTA MONICA CA 90404', stream_type = 3)
    dc = DataCollector(uid = 'SCE_62GT4UZIX', stream_type = 3)
    d, f = dc.get_data(starttime = 1470517200, endtime = 1472432400, convert_to_df = True, aggregate = 'hour')
    
    print(d)
    print(f)
